@@ -4,8 +4,9 @@
 set -e
 
 function deploy_to_pypi () {
-    pip install twine
-    python setup.py sdist bdist_wheel
+    git checkout .
+    pip3 install twine wheel
+    python3 setup.py sdist bdist_wheel
     TWINE_USERNAME=__token__ twine upload dist/*
 }
 
